# - Config file for the Dakota package
# It defines the following variables
#  Dakota_INCLUDE_DIRS - include directories for Dakota
#  Dakota_LIBRARIES    - libraries to link against
#  Dakota_EXECUTABLE   - the dakota executable

# Compute paths
get_filename_component(DAKOTA_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# Check existence since may be building/installing under
# Trilinos/TriKota, or using an external Trilinos
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
endif()

# Conservative approach for now
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
  set(Eigen3_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
endif()
include(CMakeFindDependencyMacro)
find_dependency(Eigen3)

# Our library dependencies (contains definitions for IMPORTED targets)
include("${DAKOTA_CMAKE_DIR}/DakotaTargets.cmake")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DakotaConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Build tree option not yet working
if (Dakota_BUILD_TREE)
  # Dakota's build tree doesn't have a single convenient place for headers
  set(Dakota_INCLUDE_DIRS_TMP "/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/generated/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/pecos;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/pecos/util/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/pecos/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/VPISparseGrid/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/surfpack;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/surfpack/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/src/util;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/src/surrogates;/usr/include/eigen3;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/acro/packages;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/acro/packages/utilib;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/interfaces/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/scolib/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/utilib/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/colin/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/pebbl/src/bb;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/pebbl/src/comm;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/pebbl/src/misc;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/pebbl/src/pbb;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/packages/pebbl/src/sched;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/acro/tpl/tinyxml;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/approxnn/include;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/DDACE;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/DDACE/include;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/dream;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/FSUDace;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/FSUDace;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/hopspack/src/src-shared;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-shared;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-citizens;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-evaluator;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-executor;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-framework;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/hopspack/src/src-main;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/JEGA;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/JEGA/eddy;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/JEGA/eddy;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/JEGA/include;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/NOMAD/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/NOMAD/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/OPTPP/include;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/OPTPP/include;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/rol/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/rcp;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/parameterlist;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/stacktrace;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/la;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/lapack;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/blas;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/vector;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/dynamic;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/boundconstraint;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/constraint;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/nlls;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/objective;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/operator;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/simopt;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/sketching;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/std;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/linesearch;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/trustregion;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/secant;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/krylov;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/bundle;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/augmentedlagrangian;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/moreauyosidapenalty;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/interiorpoint;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/nonlinearcg;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/fletcher;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/algorithm;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/status;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/distribution;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/expectationquad;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/fdivergence;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/spectral;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/error;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/regret;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/deviation;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/probability;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/progressivehedging;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm/PrimalDual;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/vector;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler/SROM;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/status;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/elementwise;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/utils;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/utils/function_bindings;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/zoo;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/rol/src/zoo/testproblems;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/packages/external/PSUADE;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/ampl")
  # This won't work yet.  Since Dakota is in a build tree the
  # libraries are scattered, but the import doesn't know where they
  # are.
  set(Dakota_LIBRARY_DIRS_TMP "/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/numerics/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/comm/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/parameterlist/src;/tmp/SBo/slackrepo.hYhfkL/build_dakota/dakota-6.19.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/parser/src")
else()
  set_and_check(Dakota_INCLUDE_DIRS_TMP "${PACKAGE_PREFIX_DIR}/include")
  set_and_check(Dakota_LIB_DIRS_TMP "${PACKAGE_PREFIX_DIR}/lib")
endif()

# Variables intended for use by other projects

set_and_check(Dakota_DIR ${DAKOTA_CMAKE_DIR})

# TODO: reference in src vs bin
set(Dakota_EXECUTABLE dakota)


set(Dakota_DEFINES "HAVE_CONFIG_H;HAVE_DAKOTA_SURROGATES;HAVE_CONFIG_H;DISABLE_DAKOTA_CONFIG_H;BOOST_DISABLE_ASSERTS;HAVE_UNISTD_H;HAVE_SYSTEM;HAVE_WORKING_FORK;HAVE_WORKING_VFORK;HAVE_SYS_WAIT_H;HAVE_;HAVE_SURFPACK;HAVE_DAKOTA_SURROGATES;DAKOTA_F90;HAVE_ACRO;DAKOTA_UTILIB;HAVE_APPROXNN;HAVE_ADAPTIVE_SAMPLING;HAVE_CONMIN;HAVE_DDACE;HAVE_DREAM;HAVE_FSUDACE;DAKOTA_HOPS;HAVE_JEGA;HAVE_NCSU;HAVE_NL2SOL;HAVE_NOMAD;HAVE_OPTPP;DAKOTA_OPTPP;HAVE_ROL;HAVE_PSUADE;HAVE_AMPL")

set(Dakota_INCLUDE_DIRS ${Dakota_INCLUDE_DIRS_TMP})

set(Dakota_LIBRARY_DIRS ${Dakota_LIB_DIRS_TMP})

# These are IMPORTED targets created by DakotaTargets.cmake
set(Dakota_LIBRARIES "dakota_util;dakota_surrogates;dakota_src;dakota_src_fortran;nidr;teuchosremainder;teuchosnumerics;teuchoscomm;teuchosparameterlist;teuchosparser;teuchoscore;pecos_util;pecos_src;lhs;lhs_mods;lhs_mod;dfftpack;sparsegrid;surfpack;surfpack;surfpack_fortran;utilib;colin;interfaces;scolib;3po;pebbl;tinyxml;approxnn;conmin;ddace;dream;fsudace;hopspack;jega;jega_fe;moga;soga;eutils;utilities;ncsuopt;cport;nomad;optpp;psuade;amplsolver")

# Not built in Dakota's CMake process
set(Dakota_EXTPROJ_LIBRARIES "")

# TPLs external to the build
set(Dakota_TPL_INCLUDE_DIRS "")

set(Dakota_TPL_LIBRARY_DIRS "")

include(CMakeFindDependencyMacro)
find_dependency(Boost 1.78.0 REQUIRED COMPONENTS filesystem;program_options;regex;serialization;system)

set(Dakota_TPL_LIBRARIES "/usr/lib64/liblapack.so;/usr/lib64/libblas.so")
